# Battery cycler database abstraction
Module used to provide an abstraction for a relational database used to store info 
related with battery cyclers.
It encapsulates crucial data concerning enqueued and executed experiments, as well
as compatible and employed devices within individual cycler stations. Battery details
and associated experiment profiles are also housed. Additionally, it contains generic 
power metrics captured during experiment runs, complemented by custom measures confgiured 
by the user.

Co-authors:
[Roberto Aldea](https://pypi.org/user/Raldea/), 
[Javier Sanz](https://pypi.org/user/javibu13/),
[Marius Crisan](https://pypi.org/user/mariuscrsn/)
